@@ -86,7 +86,11 @@
      VAR_AXFR = 304,
      VAR_UDP = 305,
      VAR_VERBOSITY = 306,
-     VAR_HIDE_VERSION = 307
+     VAR_HIDE_VERSION = 307,
+     VAR_RRL_SIZE = 308,
+     VAR_RRL_RATELIMIT = 309,
+     VAR_RRL_WHITELIST_RATELIMIT = 310,
+     VAR_RRL_WHITELIST = 311
    };
 #endif
 /* Tokens.  */
@@ -140,6 +144,10 @@
 #define VAR_UDP 305
 #define VAR_VERBOSITY 306
 #define VAR_HIDE_VERSION 307
+#define VAR_RRL_SIZE 308
+#define VAR_RRL_RATELIMIT 309
+#define VAR_RRL_WHITELIST_RATELIMIT 310
+#define VAR_RRL_WHITELIST 311
 
 
 
@@ -149,14 +157,14 @@ typedef union YYSTYPE
 {
 
 /* Line 2068 of yacc.c  */
-#line 40 "configparser.y"
+#line 41 "configparser.y"
 
 	char*	str;
 
 
 
 /* Line 2068 of yacc.c  */
-#line 160 "configparser.h"
+#line 168 "configparser.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
