@@ -1,7 +1,7 @@
 /*
  * nsd-xfer.c -- nsd-xfer(8).
  *
- * Copyright (c) 2001-2006, NLnet Labs. All rights reserved.
+ * Copyright (c) 2001-2011, NLnet Labs. All rights reserved.
  *
  * See LICENSE for the license.
  *
@@ -28,12 +28,10 @@
 #include "dns.h"
 #include "packet.h"
 #include "query.h"
-#include "rdata.h"
 #include "region-allocator.h"
 #include "tsig.h"
 #include "tsig-openssl.h"
 #include "util.h"
-#include "zonec.h"
 
 
 /*
@@ -169,6 +167,27 @@ connection, including optional source port.\n"
 }
 
 
+/*
+ * Find an HMAC algorithm based on its id.
+ */
+static tsig_algorithm_type *
+tsig_get_algorithm_by_id(uint8_t alg)
+{
+	if (alg == TSIG_HMAC_MD5)
+		return tsig_get_algorithm_by_name("hmac-md5");
+#ifdef HAVE_EVP_SHA1
+	if (alg == TSIG_HMAC_SHA1)
+		return tsig_get_algorithm_by_name("hmac-sha1");
+#endif /* HAVE_EVP_SHA1 */
+#ifdef HAVE_EVP_SHA256
+	if (alg == TSIG_HMAC_SHA256)
+		return tsig_get_algorithm_by_name("hmac-sha256");
+#endif /* HAVE_EVP_SHA256 */
+
+        return NULL;
+}
+
+
 /*
  * Signal handler for timeouts (SIGALRM). This function is called when
  * the alarm() value that was set counts down to zero.  This indicates
@@ -184,7 +203,6 @@ to_alarm(int ATTR_UNUSED(sig))
 	timeout_flag = 1;
 }
 
-#ifdef TSIG
 /*
  * Read a line from IN.  If successful, the line is stripped of
  * leading and trailing whitespace and non-zero is returned.
@@ -292,7 +310,6 @@ read_tsig_key(region_type *region,
 
 	return key;
 }
-#endif /* TSIG */
 
 /*
  * Read SIZE bytes from the socket into BUF.  Keep reading unless an
@@ -783,10 +800,8 @@ main(int argc, char *argv[])
 	int default_family = DEFAULT_AI_FAMILY;
 	struct sigaction mysigaction;
 	FILE *zone_file;
-#ifdef TSIG
 	const char *tsig_key_filename = NULL;
 	tsig_key_type *tsig_key = NULL;
-#endif /* TSIG */
 	axfr_state_type state;
 
 	log_init("nsd-xfer");
@@ -859,12 +874,8 @@ main(int argc, char *argv[])
 			break;
 		}
 		case 'T':
-#ifdef TSIG
 			tsig_key_filename = optarg;
 			break;
-#else
-			log_msg(LOG_ERR, "option -T given but TSIG not enabled");
-#endif /* TSIG */
 		case 'v':
 			++state.verbose;
 			break;
@@ -885,7 +896,6 @@ main(int argc, char *argv[])
 	if (argc == 0 || !zone_filename || !state.zone)
 		usage();
 
-#ifdef TSIG
 	if (tsig_key_filename) {
 		tsig_algorithm_type *tsig_algo = NULL;
 		tsig_key = read_tsig_key(
@@ -902,7 +912,6 @@ main(int argc, char *argv[])
 		tsig_create_record(state.tsig, region);
 		tsig_init_record(state.tsig, tsig_algo, tsig_key);
 	}
-#endif /* TSIG */
 
 	mysigaction.sa_handler = to_alarm;
 	sigfillset(&mysigaction.sa_mask);
@@ -946,7 +955,7 @@ main(int argc, char *argv[])
 		}
 
 		for (res = res0; res; res = res->ai_next) {
-			if (res->ai_addrlen > sizeof(q.addr))
+			if (res->ai_addrlen > (socklen_t)sizeof(q.addr))
 				continue;
 
 			/*
