@@ -101,17 +101,21 @@
      T_DHCID = 319,
      T_NSEC3PARAM = 320,
      T_TLSA = 321,
-     DOLLAR_TTL = 322,
-     DOLLAR_ORIGIN = 323,
-     NL = 324,
-     SP = 325,
-     STR = 326,
-     PREV = 327,
-     BITLAB = 328,
-     T_TTL = 329,
-     T_RRCLASS = 330,
-     URR = 331,
-     T_UTYPE = 332
+     T_NID = 322,
+     T_L32 = 323,
+     T_L64 = 324,
+     T_LP = 325,
+     DOLLAR_TTL = 326,
+     DOLLAR_ORIGIN = 327,
+     NL = 328,
+     SP = 329,
+     STR = 330,
+     PREV = 331,
+     BITLAB = 332,
+     T_TTL = 333,
+     T_RRCLASS = 334,
+     URR = 335,
+     T_UTYPE = 336
    };
 #endif
 /* Tokens.  */
@@ -179,17 +183,21 @@
 #define T_DHCID 319
 #define T_NSEC3PARAM 320
 #define T_TLSA 321
-#define DOLLAR_TTL 322
-#define DOLLAR_ORIGIN 323
-#define NL 324
-#define SP 325
-#define STR 326
-#define PREV 327
-#define BITLAB 328
-#define T_TTL 329
-#define T_RRCLASS 330
-#define URR 331
-#define T_UTYPE 332
+#define T_NID 322
+#define T_L32 323
+#define T_L64 324
+#define T_LP 325
+#define DOLLAR_TTL 326
+#define DOLLAR_ORIGIN 327
+#define NL 328
+#define SP 329
+#define STR 330
+#define PREV 331
+#define BITLAB 332
+#define T_TTL 333
+#define T_RRCLASS 334
+#define URR 335
+#define T_UTYPE 336
 
 
 
@@ -212,7 +220,7 @@ typedef union YYSTYPE
 
 
 /* Line 2068 of yacc.c  */
-#line 216 "zparser.h"
+#line 224 "zparser.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
